@@ -2,8 +2,9 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2024 Osimis S.A., Belgium
- * Copyright (C) 2021-2024 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
+ * Copyright (C) 2017-2023 Osimis S.A., Belgium
+ * Copyright (C) 2024-2025 Orthanc Team SRL, Belgium
+ * Copyright (C) 2021-2025 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -356,7 +357,7 @@ namespace OrthancPlugins
     assert(converted.GetSize() == converted.GetWidth() * converted.GetHeight() * 
            GetBytesPerPixel(converted.GetFormat()));
     result["Orthanc"]["Compression"] = "Deflate";
-    result["sizeInBytes"] = converted.GetSize();
+    result["sizeInBytes"] = static_cast<Json::Value::UInt64>(converted.GetSize());
 
     std::string z;
     CompressUsingDeflate(z, GetGlobalContext(), converted.GetConstBuffer(), converted.GetSize());
@@ -481,7 +482,7 @@ namespace OrthancPlugins
     
     result["Orthanc"]["IsSigned"] = (accessor.GetFormat() == Orthanc::PixelFormat_SignedGrayscale16);
     result["Orthanc"]["Compression"] = "Jpeg";
-    result["sizeInBytes"] = converted.GetSize();
+    result["sizeInBytes"] = static_cast<Json::Value::UInt64>(converted.GetSize());
 
     std::string jpeg;
     WriteJpegToMemory(jpeg, GetGlobalContext(), converted, quality);
